@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Module::Generate;
 use base 'Import::Export';
@@ -15,7 +15,7 @@ our %EX = (
 
 sub generate {
 	my (%generate) = scalar @_ > 1 ? @_ : %{$_[0]};
-	my $gen = Module::Generate->new;
+	my $gen = Module::Generate->start;
 	$generate{$_} && $gen->$_($generate{$_})
 		for (qw/dist lib author email version/);
 	_build_classes($gen, $generate{classes});
@@ -32,12 +32,16 @@ sub _build_classes {
 			] : $mod;
 			sprintf( '%s::%s', $mod, $class );
 		} : $class;
-		my ($cls, $subs, $subclass) = (
-			$gen->class($kls),
+		my ($cls, $new, $subs, $accessors, $subclass) = (
+			$gen->class($kls)->new,
+			delete $classes->{$class}{new},
 			delete $classes->{$class}{subs},
+			delete $classes->{$class}{accessors},
 			delete $classes->{$class}{subclass}
 		);
 		_itterate_keys($cls, $classes->{$class});
+		_itterate_keys($cls, $new);
+		$cls->accessor($_) for (@{$accessors});
 		while (scalar @{$subs}) {
 			my ($key, $value) = (shift @{$subs}, shift @{$subs});
 			my $sub = $cls->sub($key);
@@ -65,7 +69,7 @@ Module::Generate::Hash - Assisting with module generation.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
@@ -85,11 +89,10 @@ Version 0.02
 				begin => sub {
 					$type = 'boeing';
 				},
-				subs => [
-					new => {
-						code => sub { return bless {}, $_[0] },
-						example => 'my $plane = Planes->new',
-					},
+				accessors => [qw/
+					airline
+				/],
+				subs => [	
 					type => {
 						code => sub { $type },
 						pod => 'Returns the type of plane.',
@@ -130,7 +133,7 @@ automatically be notified of progress on your bug as I make changes.
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc Module::Generate::Hash
+	perldoc Module::Generate::Hash
 
 
 You can also look for information at:
